@@ -18,7 +18,7 @@
 #' @export
 recon_con1 <- function(
   infile,
-  outdir,
+  outdir = NULL,
   subjid,
   verbose = TRUE
   ) {
@@ -30,12 +30,26 @@ recon_con1 <- function(
            opts = "-autorecon1")
 }
 
-
+#' @rdname recon_manual
+#' @export
+autorecon1 <- function(
+  infile,
+  outdir = NULL,
+  subjid,
+  verbose = TRUE
+) {
+  recon_con1(
+    infile = infile,
+    outdir = outdir,
+    subjid = subjid,
+    verbose = verbose)
+}
+  
 #' @rdname recon_manual
 #' @export
 recon_con2 <- function(
   infile,
-  outdir,
+  outdir = NULL,
   subjid,
   verbose = TRUE
 ) {
@@ -47,11 +61,26 @@ recon_con2 <- function(
            opts = "-autorecon2")
 }
 
+#' @rdname recon_manual
+#' @export
+autorecon2 <- function(
+  infile,
+  outdir = NULL,
+  subjid,
+  verbose = TRUE
+) {
+  recon_con2(
+    infile = infile,
+    outdir = outdir,
+    subjid = subjid,
+    verbose = verbose)
+}
+
 #' @rdname recon_manual
 #' @export
 recon_con3 <- function(
   infile,
-  outdir,
+  outdir = NULL,
   subjid,
   verbose = TRUE
 ) {
@@ -61,4 +90,19 @@ recon_con3 <- function(
            subjid = subjid,
            verbose = verbose,
            opts = "-autorecon3")
-}
\ No newline at end of file
+}
+
+#' @rdname recon_manual
+#' @export
+autorecon3 <- function(
+  infile,
+  outdir = NULL,
+  subjid,
+  verbose = TRUE
+) {
+  recon_con3(
+    infile = infile,
+    outdir = outdir,
+    subjid = subjid,
+    verbose = verbose)
+}
